//------------------------------------------------------------------------------------
// runge_kutt.h
//     .   dy/dx=F(x,y)
//  -
// :  , nevsoft@mail.ru
// 24.05.2005
//------------------------------------------------------------------------------------

#include <vector>

namespace Mathematics
{

typedef std::pair<double, double> pair_of_doubles;

//  RungeKuttStep      -.     
//    (  )
//       dy/dx=F(x,y)
// x -   . X
// y -   . Y
// h -  
// F -    ,     (x,y) 
//            (
//	     
//       x+h

double RungeKuttStep(double x, double y, double h, double (*F)(double x, double y));

//  RungeKutt    x,y  ,  
//  dy/dx=F(x,y)   .
// x0 -   . X
// y0 -   . Y
// xn -   . X
// h -  
// F -    ,     (x,y) 
//            (
//	     
// result -       (x,y).    (x[i]+h)>xn
//   true   ,  false
//        

bool RungeKutt(double x0, double y0, double xn, double h, double (*F)(double x, double y), std::vector<pair_of_doubles> &result) throw();

} // namespace Mathematics